@@ -25,4 +25,8 @@
 #'
 #' @docType package
 #' @name rerddapXtracto
+#' @keywords internal
+"_PACKAGE"
+## usethis namespace: start
+## usethis namespace: end
 NULL
